@@ -240,6 +240,12 @@ resources_update_operations = [
          "value": {"type": "string", "min_length": 0, "max_length": 255,
                    "required": False}
      }]},
+    {"desc": "add loadbalancer resource type",
+     "type": "create_resource_type",
+     "resource_type": "loadbalancer",
+     "data": [{
+         "attributes": {}
+     }]},
 ]
 
 # NOTE(sileht): We use LooseVersion because pbr can generate invalid
@@ -252,13 +258,13 @@ def upgrade_resource_types(conf):
 
     gnocchi_version = version.LooseVersion(gnocchi.build.get())
     if gnocchi_version < REQUIRED_VERSION:
-        raise Exception("required gnocchi version is %s, got %s",
-                        REQUIRED_VERSION, gnocchi_version)
+        raise Exception("required gnocchi version is %s, got %s" %
+                        (REQUIRED_VERSION, gnocchi_version))
 
     for name, attributes in resources_initial.items():
         try:
             gnocchi.resource_type.get(name=name)
-        except gnocchi_exc.ResourceTypeNotFound:
+        except (gnocchi_exc.ResourceTypeNotFound, gnocchi_exc.NotFound):
             rt = {'name': name, 'attributes': attributes}
             gnocchi.resource_type.create(resource_type=rt)
 
@@ -275,7 +281,7 @@ def upgrade_resource_types(conf):
         elif ops['type'] == 'create_resource_type':
             try:
                 gnocchi.resource_type.get(name=ops['resource_type'])
-            except gnocchi_exc.ResourceTypeNotFound:
+            except (gnocchi_exc.ResourceTypeNotFound, gnocchi_exc.NotFound):
                 rt = {'name': ops['resource_type'],
                       'attributes': ops['data'][0]['attributes']}
                 gnocchi.resource_type.create(resource_type=rt)
