@@ -13,8 +13,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import warnings
+
 from oslo_log import log
-from oslo_utils import timeutils
 
 from ceilometer.i18n import _
 from ceilometer.network.services import base
@@ -33,6 +34,13 @@ class FirewallPollster(base.BaseServicesPollster):
               'firewall_policy_id',
               ]
 
+    def __init__(self, conf):
+        super(FirewallPollster, self).__init__(conf)
+
+        warnings.warn('Support for Neutron FWaaS has been deprecated '
+                      'and will be removed in a future release.',
+                      category=DeprecationWarning, stacklevel=3)
+
     @property
     def default_discovery(self):
         return 'fw_services'
@@ -58,7 +66,6 @@ class FirewallPollster(base.BaseServicesPollster):
                 user_id=None,
                 project_id=fw['tenant_id'],
                 resource_id=fw['id'],
-                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=self.extract_metadata(fw)
             )
 
@@ -74,6 +81,13 @@ class FirewallPolicyPollster(base.BaseServicesPollster):
               'audited',
               ]
 
+    def __init__(self, conf):
+        super(FirewallPolicyPollster, self).__init__(conf)
+
+        warnings.warn('Support for Neutron FWaaS has been deprecated '
+                      'and will be removed in a future release.',
+                      category=DeprecationWarning, stacklevel=3)
+
     @property
     def default_discovery(self):
         return 'fw_policy'
@@ -92,6 +106,5 @@ class FirewallPolicyPollster(base.BaseServicesPollster):
                 user_id=None,
                 project_id=fw['tenant_id'],
                 resource_id=fw['id'],
-                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=self.extract_metadata(fw)
             )
