@@ -282,22 +282,31 @@ class GnocchiPublisher(publisher.ConfigPublisherBase):
             return self._gnocchi_project_id
         with self._gnocchi_project_id_lock:
             if self._gnocchi_project_id is None:
+                if not self.filter_project:
+                    LOG.debug(
+                        "Multiple executions were locked on "
+                        "self._gnocchi_project_id_lock`. This execution "
+                        "should no call `_internal_gnocchi_project_discovery` "
+                        "as `self.filter_project` is None.")
+                    return None
                 try:
                     project = self._ks_client.projects.find(
                         name=self.filter_project,
                         domain=self.filter_domain)
                 except ka_exceptions.NotFound:
-                    LOG.warning('filtered project not found in keystone,'
-                                ' ignoring the filter_project '
-                                'option')
+                    LOG.warning('Filtered project [%s] not found in keystone, '
+                                'ignoring the filter_project option' %
+                                self.filter_project)
+
                     self.filter_project = None
                     return None
                 except Exception:
-                    LOG.exception('fail to retrieve filtered project ')
+                    LOG.exception('Failed to retrieve filtered project [%s].'
+                                  % self.filter_project)
                     raise
                 self._gnocchi_project_id = project.id
-                LOG.debug("filtered project found: %s",
-                          self._gnocchi_project_id)
+                LOG.debug("Filtered project [%s] found with ID [%s].",
+                          self.filter_project, self._gnocchi_project_id)
             return self._gnocchi_project_id
 
     def _is_swift_account_sample(self, sample):
@@ -322,12 +331,41 @@ class GnocchiPublisher(publisher.ConfigPublisherBase):
             if operation:
                 return rd, operation
 
+    def filter_gnocchi_activity_openstack(self, samples):
+        """Skip sample generated by gnocchi itself
+
+        This method will filter out the samples that are generated by
+        Gnocchi itself.
+        """
+        filtered_samples = []
+        for sample in samples:
+            if not self._is_gnocchi_activity(sample):
+                filtered_samples.append(sample)
+                LOG.debug("Sample [%s] is not a Gnocchi activity; therefore, "
+                          "we do not filter it out and push it to Gnocchi.",
+                          sample)
+            else:
+                LOG.debug("Sample [%s] is a Gnocchi activity; therefore, "
+                          "we filter it out and do not push it to Gnocchi.",
+                          sample)
+        return filtered_samples
+
     def publish_samples(self, data):
         self.ensures_archives_policies()
 
-        # NOTE(sileht): skip sample generated by gnocchi itself
-        data = [s for s in data if not self._is_gnocchi_activity(s)]
-        data.sort(key=operator.attrgetter('resource_id'))
+        data = self.filter_gnocchi_activity_openstack(data)
+
+        def value_to_sort(object_to_sort):
+            value = object_to_sort.resource_id
+            if not value:
+                LOG.debug("Resource ID was not defined for sample data [%s]. "
+                          "Therefore, we will use an empty string as the "
+                          "resource ID.", object_to_sort)
+                value = ''
+
+            return value
+
+        data.sort(key=value_to_sort)
         resource_grouped_samples = itertools.groupby(
             data, key=operator.attrgetter('resource_id'))
 
