@@ -126,7 +126,9 @@ def meter_message_from_counter(sample, secret):
            'counter_unit': sample.unit,
            'counter_volume': sample.volume,
            'user_id': sample.user_id,
+           'user_name': sample.user_name,
            'project_id': sample.project_id,
+           'project_name': sample.project_name,
            'resource_id': sample.resource_id,
            'timestamp': sample.timestamp,
            'resource_metadata': sample.resource_metadata,
