@@ -21,9 +21,7 @@ import fixtures
 import oslo_messaging.conffixture
 from oslo_utils import timeutils
 from oslotest import base
-import six
 from testtools import testcase
-import webtest
 import yaml
 
 import ceilometer
@@ -97,11 +95,7 @@ def _skip_decorator(func):
         try:
             return func(*args, **kwargs)
         except ceilometer.NotImplementedError as e:
-            raise testcase.TestSkipped(six.text_type(e))
-        except webtest.app.AppError as e:
-            if 'not implemented' in six.text_type(e):
-                raise testcase.TestSkipped(six.text_type(e))
-            raise
+            raise testcase.TestSkipped(str(e))
     return skip_if_not_implemented
 
 
