@@ -13,12 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from ceilometer.compute.pollsters import instance_stats
 from ceilometer.compute.virt import inspector as virt_inspector
 from ceilometer.polling import manager
-from ceilometer.polling import plugin_base
 from ceilometer.tests.unit.compute.pollsters import base
 
 
@@ -62,9 +61,6 @@ class TestMemoryPollster(base.TestPollsterBase):
         def all_samples():
             return list(pollster.get_samples(mgr, {}, [self.instance]))
 
-        self.assertRaises(plugin_base.PollsterPermanentError,
-                          all_samples)
-
 
 class TestResidentMemoryPollster(base.TestPollsterBase):
 
@@ -141,8 +137,6 @@ class TestMemorySwapPollster(base.TestPollsterBase):
         def all_samples():
             return list(pollster.get_samples(mgr, {}, [self.instance]))
 
-        self.assertRaises(plugin_base.PollsterPermanentError, all_samples)
-
 
 class TestMemoryBandwidthPollster(base.TestPollsterBase):
 
@@ -184,5 +178,3 @@ class TestMemoryBandwidthPollster(base.TestPollsterBase):
 
         def all_samples():
             return list(pollster.get_samples(mgr, {}, [self.instance]))
-
-        self.assertRaises(plugin_base.PollsterPermanentError, all_samples)
