@@ -18,7 +18,6 @@ from unittest import mock
 import fixtures
 from oslo_utils import netutils
 from pysnmp.proto import rfc1905
-import six
 
 from ceilometer.hardware.inspector import snmp
 from ceilometer.tests import base as test_base
@@ -45,7 +44,7 @@ class FakeCommandGenerator(object):
             for oid in oids
             if oid not in emptyOIDs
         ]
-        for emptyOID, exc in six.iteritems(emptyOIDs):
+        for emptyOID, exc in emptyOIDs.items():
             if emptyOID in oids:
                 varBinds += [(FakeObjectName(emptyOID), exc)]
         return (None, None, 0, varBinds)
