@@ -339,9 +339,9 @@ class PublisherTest(base.BaseTestCase):
     def test_activity_gnocchi_project_not_found(self, logger):
         self.ks_client.projects.find.side_effect = ka_exceptions.NotFound
         self._do_test_activity_filter(2)
-        logger.warning.assert_called_with('filtered project not found in '
-                                          'keystone, ignoring the '
-                                          'filter_project option')
+        logger.warning.assert_called_with(
+            'Filtered project [service] not found in keystone, ignoring the '
+            'filter_project option')
 
     def test_activity_filter_match_swift_event(self):
         self.samples[0].name = 'storage.objects.outgoing.bytes'
@@ -375,18 +375,30 @@ class PublisherTest(base.BaseTestCase):
     @mock.patch('ceilometer.publisher.gnocchi.GnocchiPublisher'
                 '.batch_measures')
     def test_unhandled_meter_with_no_resource_id(self, fake_batch):
-        samples = [sample.Sample(
-            name='unknown.meter',
-            unit='GB',
-            type=sample.TYPE_GAUGE,
-            volume=2,
-            user_id='test_user',
-            project_id='test_project',
-            source='openstack',
-            timestamp='2014-05-08 20:23:48.028195',
-            resource_id=None,
-            resource_metadata={}
-        )]
+        samples = [
+            sample.Sample(
+                name='unknown.meter',
+                unit='GB',
+                type=sample.TYPE_GAUGE,
+                volume=2,
+                user_id='test_user',
+                project_id='test_project',
+                source='openstack',
+                timestamp='2014-05-08 20:23:48.028195',
+                resource_id=None,
+                resource_metadata={}),
+            sample.Sample(
+                name='unknown.meter',
+                unit='GB',
+                type=sample.TYPE_GAUGE,
+                volume=2,
+                user_id='test_user',
+                project_id='test_project',
+                source='openstack',
+                timestamp='2014-05-08 20:23:48.028195',
+                resource_id="Some-other-resource-id",
+                resource_metadata={})
+        ]
         url = netutils.urlsplit("gnocchi://")
         d = gnocchi.GnocchiPublisher(self.conf.conf, url)
         d._already_checked_archive_policies = True
@@ -723,8 +735,11 @@ class PublisherWorkflowTest(base.BaseTestCase,
                 create_metrics=True)
         ]
         expected_debug = [
-            mock.call('filtered project found: %s',
+            mock.call('Filtered project [%s] found with ID [%s].', 'service',
                       'a2d42c23-d518-46b6-96ab-3fba2e146859'),
+            mock.call('Sample [%s] is not a Gnocchi activity; therefore, we '
+                      'do not filter it out and push it to Gnocchi.',
+                      self.sample),
             mock.call('Processing sample [%s] for resource ID [%s].',
                       self.sample, resource_id),
         ]
